@@ -367,7 +367,7 @@ QVariant KConfigGroup::convertToQVariant(const char *pKey, const QByteArray &val
     case QMetaType::QFont:
         qWarning() << "KConfigGroup::readEntry was passed GUI type '"
                    << aDefault.typeName()
-                   << "' but kdeui isn't linked! If it is linked to your program, "
+                   << "' but KConfigGui isn't linked! If it is linked to your program, "
                    "this is a platform bug. Please inform the KDE developers";
         break;
     case QMetaType::QUrl:
@@ -416,24 +416,13 @@ static QString translatePath(QString path)   // krazy:exclude=passbyvalue
     // only "our" $HOME should be interpreted
     path.replace(QLatin1Char('$'), QLatin1String("$$"));
 
-    bool startsWithFile = path.startsWith(QLatin1String("file:"), Qt::CaseInsensitive);
+    const bool startsWithFile = path.startsWith(QLatin1String("file:"), Qt::CaseInsensitive);
+    path = startsWithFile ? QUrl(path).toLocalFile() : path;
 
-    // return original path, if it refers to another type of URL (e.g. http:/), or
-    // if the path is already relative to another directory
-    if ((!startsWithFile && QFileInfo(path).isRelative()) ||
-            (startsWithFile && QFileInfo(path.mid(5)).isRelative())) {
+    if (QDir::isRelativePath(path)) {
         return path;
     }
 
-    if (startsWithFile) {
-        path.remove(0, 5);    // strip leading "file:/" off the string
-    }
-
-    // keep only one single '/' at the beginning - needed for cleanHomeDirPath()
-    while (path[0] == QLatin1Char('/') && path[1] == QLatin1Char('/')) {
-        path.remove(0, 1);
-    }
-
     // we can not use KGlobal::dirs()->relativeLocation("home", path) here,
     // since it would not recognize paths without a trailing '/'.
     // All of the 3 following functions to return the user's home directory
@@ -448,7 +437,7 @@ static QString translatePath(QString path)   // krazy:exclude=passbyvalue
     }
 
     if (startsWithFile) {
-        path.prepend(QStringLiteral("file://"));
+        path = QUrl::fromLocalFile(path).toString();
     }
 
     return path;
@@ -664,7 +653,7 @@ QString KConfigGroup::readEntryUntranslated(const char *key, const QString &aDef
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::readEntryUntranslated", "accessing an invalid group");
 
-    QString result = config()->d_func()->lookupData(d->fullName(), key, KEntryMap::SearchFlags(), 0);
+    QString result = config()->d_func()->lookupData(d->fullName(), key, KEntryMap::SearchFlags(), nullptr);
     if (result.isNull()) {
         return aDefault;
     }
@@ -1052,7 +1041,7 @@ void KConfigGroup::writeEntry(const char *key, const QVariant &value,
     case QMetaType::QFont:
         qWarning() << "KConfigGroup::writeEntry was passed GUI type '"
                    << value.typeName()
-                   << "' but kdeui isn't linked! If it is linked to your program, this is a platform bug. "
+                   << "' but KConfigGui isn't linked! If it is linked to your program, this is a platform bug. "
                    "Please inform the KDE developers";
         break;
     case QMetaType::QUrl:
@@ -1254,7 +1243,7 @@ bool KConfigGroup::isGroupImmutableImpl(const QByteArray &b) const
 void KConfigGroup::copyTo(KConfigBase *other, WriteConfigFlags pFlags) const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::copyTo", "accessing an invalid group");
-    Q_ASSERT(other != Q_NULLPTR);
+    Q_ASSERT(other != nullptr);
 
     if (KConfigGroup *otherGroup = dynamic_cast<KConfigGroup *>(other)) {
         config()->d_func()->copyGroup(d->fullName(), otherGroup->d->fullName(), otherGroup, pFlags);
@@ -1271,7 +1260,7 @@ void KConfigGroup::reparent(KConfigBase *parent, WriteConfigFlags pFlags)
     Q_ASSERT_X(isValid(), "KConfigGroup::reparent", "accessing an invalid group");
     Q_ASSERT_X(!d->bConst, "KConfigGroup::reparent", "reparenting a read-only group");
     Q_ASSERT_X(!d->bImmutable, "KConfigGroup::reparent", "reparenting an immutable group");
-    Q_ASSERT(parent != Q_NULLPTR);
+    Q_ASSERT(parent != nullptr);
 
     KConfigGroup oldGroup(*this);
 
